@@ -3,6 +3,7 @@ import importlib.metadata
 import logging
 import os
 import pathlib
+import typing
 import urllib.parse
 import uuid
 from decimal import Decimal
@@ -64,7 +65,7 @@ class TestCasting:
         assert env("NOT_SET", "mydefault") == "mydefault"
         with pytest.raises(
             environs.EnvError,
-            match='Environment variable "NOT_SET" not set',
+            match=r'Environment variable "NOT_SET" not set',
         ):
             assert env("NOT_SET")
 
@@ -89,7 +90,7 @@ class TestCasting:
         set_env({"INT": "invalid"})
         with pytest.raises(
             environs.EnvValidationError,
-            match='Environment variable "INT" invalid',
+            match=r'Environment variable "INT" invalid',
         ) as excinfo:
             env.int("INT")
         exc = excinfo.value
@@ -416,7 +417,7 @@ class TestCasting:
         set_env({"COLOR": "GREEN"})
         with pytest.raises(
             environs.EnvError,
-            match='Environment variable "COLOR" invalid:',
+            match=r'Environment variable "COLOR" invalid:',
         ):
             assert env.enum("COLOR", enum=Color, by_value=True)
         set_env({"COLOR": "green"})
@@ -426,7 +427,7 @@ class TestCasting:
         set_env({"DAY": "SUNDAY"})
         with pytest.raises(
             environs.EnvError,
-            match='Environment variable "DAY" invalid:',
+            match=r'Environment variable "DAY" invalid:',
         ):
             assert env.enum("DAY", enum=Day, by_value=fields.Int())
         set_env({"DAY": "1"})
@@ -436,7 +437,7 @@ class TestCasting:
         set_env({"DAY": "suNDay"})
         with pytest.raises(
             environs.EnvError,
-            match="Must be one of: SUNDAY, MONDAY, TUESDAY",
+            match=r"Must be one of: SUNDAY, MONDAY, TUESDAY",
         ):
             assert env.enum("DAY", enum=Day)
 
@@ -497,7 +498,7 @@ class TestEnvFileReading:
         assert env("CUSTOM_STRING") == "foo"
 
     def test_read_env_directory(self, env: environs.Env):
-        with pytest.raises(ValueError, match="path must be a filename"):
+        with pytest.raises(ValueError, match=r"path must be a filename"):
             assert env.read_env("tests")
 
     def test_read_env_return_path(self, env: environs.Env):
@@ -746,7 +747,7 @@ class TestPrefix:
         with env.prefixed("APP_"):
             with pytest.raises(
                 environs.EnvError,
-                match='Environment variable "APP_INT" invalid',
+                match=r'Environment variable "APP_INT" invalid',
             ):
                 env.int("INT", validate=validate)
 
@@ -921,7 +922,7 @@ class TestDeferredValidation:
         env.seal()
         with pytest.raises(
             environs.EnvSealedError,
-            match="Env has already been sealed",
+            match=r"Env has already been sealed",
         ):
             env.int("INT")
 
@@ -935,7 +936,7 @@ class TestDeferredValidation:
         env.seal()
         with pytest.raises(
             environs.EnvSealedError,
-            match="Env has already been sealed",
+            match=r"Env has already been sealed",
         ):
             env.https_url("URL")
 
@@ -1046,7 +1047,7 @@ class TestExpandVars:
 
         with pytest.raises(
             environs.EnvError,
-            match='Environment variable "MYVAR" not set',
+            match=r'Environment variable "MYVAR" not set',
         ):
             env.str("UNDEFINED")
 
@@ -1065,7 +1066,7 @@ class TestExpandVars:
 
         with pytest.raises(
             environs.EnvError,
-            match='Environment variable "WORLD" not set',
+            match=r'Environment variable "WORLD" not set',
         ):
             env.str("HELLOWORLD")
 
@@ -1120,9 +1121,34 @@ class TestFileAwareEnv:
 
         return _set_env_file
 
-    def test_read_from_file(self, fa_env, set_env_file):
-        set_env_file("KEY", "value from file")
-        assert fa_env.str("KEY") == "value from file"
+    @pytest.mark.parametrize(
+        ("key", "value", "kwargs", "expected"),
+        [
+            ("KEY", "value from file", {}, "value from file"),
+            (
+                "DO_NOT_STRIP_WHITESPACE",
+                " value from file with leading and trailing whitespaces \n",
+                {},
+                " value from file with leading and trailing whitespaces \n",
+            ),
+            (
+                "STRIP_WHITESPACE",
+                "\n  value from file with leading and trailing whitespaces \n",
+                {"strip_whitespace": True},
+                "value from file with leading and trailing whitespaces",
+            ),
+        ],
+    )
+    def test_read_from_file(
+        self,
+        set_env_file,
+        key: str,
+        value: str,
+        kwargs: dict[str, typing.Any],
+        expected: str,
+    ):
+        set_env_file(key, value)
+        assert environs.FileAwareEnv(**kwargs).str(key) == expected
 
     def test_read_from_file_overrides_key(self, fa_env, set_env_file, set_env):
         set_env_file("KEY", "value from file")
@@ -1142,7 +1168,7 @@ class TestFileAwareEnv:
         )
 
         with pytest.raises(
-            ValueError, match="The value of KEY_FILE must be a readable file path."
+            ValueError, match=r"The value of KEY_FILE must be a readable file path."
         ):
             fa_env.str("KEY")
 
@@ -1156,7 +1182,7 @@ class TestFileAwareEnv:
         )
 
         with pytest.raises(
-            ValueError, match="The value of KEY_FILE must be a readable file path."
+            ValueError, match=r"The value of KEY_FILE must be a readable file path."
         ):
             fa_env.str("KEY")
 
@@ -1171,7 +1197,7 @@ class TestFileAwareEnv:
         )
 
         with pytest.raises(
-            ValueError, match="The value of KEY_FILE must be a readable file path."
+            ValueError, match=r"The value of KEY_FILE must be a readable file path."
         ):
             assert fa_env.str("KEY")
 
